# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class IndicativeImbalanceSettlementApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get(self, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Acceptance volumes by settlement date (BOAV)  # noqa: E501

        Returns the settlement acceptance volumes for the requested settlement date.    For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get(settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get_with_http_info(settlement_date, bid_offer, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get_with_http_info(settlement_date, bid_offer, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get_with_http_info(self, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Acceptance volumes by settlement date (BOAV)  # noqa: E501

        Returns the settlement acceptance volumes for the requested settlement date.    For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get_with_http_info(settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'bid_offer', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get`")  # noqa: E501
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/acceptance/volumes/all/{bidOffer}/{settlementDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get(self, settlement_period, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Acceptance volumes by settlement period (BOAV)  # noqa: E501

        Returns the settlement acceptance volumes for the requested settlement period.    Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get(settlement_period, settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, bid_offer, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, bid_offer, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(self, settlement_period, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Acceptance volumes by settlement period (BOAV)  # noqa: E501

        Returns the settlement acceptance volumes for the requested settlement period.    Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_period', 'settlement_date', 'bid_offer', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/acceptance/volumes/all/{bidOffer}/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_acceptances_all_settlement_date_settlement_period_get(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Historic acceptances by settlement period (ISPSTACK, BOALF, BOD)  # noqa: E501

        Returns the bid and offer prices for acceptances, with the acceptance number and acceptance time. Results are sorted by descending acceptance time.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_acceptances_all_settlement_date_settlement_period_get(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_acceptances_all_settlement_date_settlement_period_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_acceptances_all_settlement_date_settlement_period_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_acceptances_all_settlement_date_settlement_period_get_with_http_info(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Historic acceptances by settlement period (ISPSTACK, BOALF, BOD)  # noqa: E501

        Returns the bid and offer prices for acceptances, with the acceptance number and acceptance time. Results are sorted by descending acceptance time.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_acceptances_all_settlement_date_settlement_period_get_with_http_info(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'settlement_period', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_acceptances_all_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_acceptances_all_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_acceptances_all_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/acceptances/all/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_default_notices_get(self, **kwargs):  # noqa: E501
        """Default notices (CDN)  # noqa: E501

        This endpoint provides a subset of CDN data received from EC. It returns the defaults that are in force and defaults that have closed within the last 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_default_notices_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingCreditDefaultNoticeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_default_notices_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_default_notices_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def balancing_settlement_default_notices_get_with_http_info(self, **kwargs):  # noqa: E501
        """Default notices (CDN)  # noqa: E501

        This endpoint provides a subset of CDN data received from EC. It returns the defaults that are in force and defaults that have closed within the last 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_default_notices_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingCreditDefaultNoticeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_default_notices_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/default-notices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingCreditDefaultNoticeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get(self, bid_offer, settlement_date, **kwargs):  # noqa: E501
        """Indicative period BMU cashflows by settlement date (EBOCF)  # noqa: E501

        Returns derived indicative cashflow data generated by the latest calculation run for a given settlement date.                For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get(bid_offer, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bid_offer: Filter if bid or offer data is to be returned. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get_with_http_info(bid_offer, settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get_with_http_info(bid_offer, settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get_with_http_info(self, bid_offer, settlement_date, **kwargs):  # noqa: E501
        """Indicative period BMU cashflows by settlement date (EBOCF)  # noqa: E501

        Returns derived indicative cashflow data generated by the latest calculation run for a given settlement date.                For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get_with_http_info(bid_offer, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bid_offer: Filter if bid or offer data is to be returned. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bid_offer', 'settlement_date', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/indicative/cashflows/all/{bidOffer}/{settlementDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get(self, settlement_period, bid_offer, settlement_date, **kwargs):  # noqa: E501
        """Indicative period BMU cashflows by settlement period (EBOCF)  # noqa: E501

        Returns derived indicative cashflow data generated by the latest calculation run for a given settlement period.                Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get(settlement_period, bid_offer, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period for the filter. (required)
        :param str bid_offer: Filter if bid or offer data is to be returned. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, bid_offer, settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, bid_offer, settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get_with_http_info(self, settlement_period, bid_offer, settlement_date, **kwargs):  # noqa: E501
        """Indicative period BMU cashflows by settlement period (EBOCF)  # noqa: E501

        Returns derived indicative cashflow data generated by the latest calculation run for a given settlement period.                Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, bid_offer, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period for the filter. (required)
        :param str bid_offer: Filter if bid or offer data is to be returned. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_period', 'bid_offer', 'settlement_date', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/indicative/cashflows/all/{bidOffer}/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get(self, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Indicative volumes by settlement date (DISPTAV)  # noqa: E501

        Returns the settlement indicative volumes for the requested settlement date.    For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get(settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get_with_http_info(settlement_date, bid_offer, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get_with_http_info(settlement_date, bid_offer, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get_with_http_info(self, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Indicative volumes by settlement date (DISPTAV)  # noqa: E501

        Returns the settlement indicative volumes for the requested settlement date.    For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get_with_http_info(settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'bid_offer', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get`")  # noqa: E501
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/indicative/volumes/all/{bidOffer}/{settlementDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get(self, settlement_period, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Indicative volumes by settlement period (DISPTAV)  # noqa: E501

        Returns the settlement indicative volumes for the requested settlement period.    Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get(settlement_period, settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, bid_offer, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, bid_offer, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(self, settlement_period, settlement_date, bid_offer, **kwargs):  # noqa: E501
        """Indicative volumes by settlement period (DISPTAV)  # noqa: E501

        Returns the settlement indicative volumes for the requested settlement period.    Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, bid_offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param str bid_offer: (required)
        :param list[str] bm_unit: Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_period', 'settlement_date', 'bid_offer', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/indicative/volumes/all/{bidOffer}/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_market_depth_settlement_date_get(self, settlement_date, **kwargs):  # noqa: E501
        """Market depth by settlement date (IMBALNGC, BOD, DISEBSP, DISPTAV)  # noqa: E501

        Returns market depth data for a given day.  Imbalance (MW) is retrieved from IMBALNGC.  Bid/offer volumes (MWh) are calculated by summing bid/offer volumes from BOD.  Total acceptance volumes (MWh) are retrieved from DISEBSP.  Priced acceptance volumes (MWh) are calculated by summing bid/offer accepted volumes with data type Original from DISPTAV.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_market_depth_settlement_date_get(settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_market_depth_settlement_date_get_with_http_info(settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_market_depth_settlement_date_get_with_http_info(settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_market_depth_settlement_date_get_with_http_info(self, settlement_date, **kwargs):  # noqa: E501
        """Market depth by settlement date (IMBALNGC, BOD, DISEBSP, DISPTAV)  # noqa: E501

        Returns market depth data for a given day.  Imbalance (MW) is retrieved from IMBALNGC.  Bid/offer volumes (MWh) are calculated by summing bid/offer volumes from BOD.  Total acceptance volumes (MWh) are retrieved from DISEBSP.  Priced acceptance volumes (MWh) are calculated by summing bid/offer accepted volumes with data type Original from DISPTAV.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_market_depth_settlement_date_get_with_http_info(settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_market_depth_settlement_date_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_market_depth_settlement_date_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/market-depth/{settlementDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_market_depth_settlement_date_settlement_period_get(self, settlement_period, settlement_date, **kwargs):  # noqa: E501
        """Market depth by settlement period (IMBALNGC, BOD, DISEBSP, DISPTAV)  # noqa: E501

        Returns market depth data for a given settlement period.  Imbalance (MW) is retrieved from IMBALNGC.  Bid/offer volumes (MWh) are calculated by summing bid/offer volumes from BOD.  Total acceptance volumes (MWh) are retrieved from DISEBSP.  Priced acceptance volumes (MWh) are calculated by summing bid/offer accepted volumes with data type Original from DISPTAV.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_market_depth_settlement_date_settlement_period_get(settlement_period, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_market_depth_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_market_depth_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_market_depth_settlement_date_settlement_period_get_with_http_info(self, settlement_period, settlement_date, **kwargs):  # noqa: E501
        """Market depth by settlement period (IMBALNGC, BOD, DISEBSP, DISPTAV)  # noqa: E501

        Returns market depth data for a given settlement period.  Imbalance (MW) is retrieved from IMBALNGC.  Bid/offer volumes (MWh) are calculated by summing bid/offer volumes from BOD.  Total acceptance volumes (MWh) are retrieved from DISEBSP.  Priced acceptance volumes (MWh) are calculated by summing bid/offer accepted volumes with data type Original from DISPTAV.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_market_depth_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_period', 'settlement_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_market_depth_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_market_depth_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_market_depth_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/market-depth/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_messages_settlement_date_get(self, settlement_date, **kwargs):  # noqa: E501
        """Settlement messages by settlement date (SMSG)  # noqa: E501

        Returns settlement messages generated by the SAA for a given settlement day, relating to the data  for a settlement run.                For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_messages_settlement_date_get(settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_messages_settlement_date_get_with_http_info(settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_messages_settlement_date_get_with_http_info(settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_messages_settlement_date_get_with_http_info(self, settlement_date, **kwargs):  # noqa: E501
        """Settlement messages by settlement date (SMSG)  # noqa: E501

        Returns settlement messages generated by the SAA for a given settlement day, relating to the data  for a settlement run.                For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_messages_settlement_date_get_with_http_info(settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_messages_settlement_date_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_messages_settlement_date_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/messages/{settlementDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_messages_settlement_date_settlement_period_get(self, settlement_period, settlement_date, **kwargs):  # noqa: E501
        """Settlement messages by settlement date and period (SMSG)  # noqa: E501

        Returns settlement messages generated by the SAA for a given settlement period, relating to the data  for a settlement run.                Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_messages_settlement_date_settlement_period_get(settlement_period, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_messages_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_messages_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_messages_settlement_date_settlement_period_get_with_http_info(self, settlement_period, settlement_date, **kwargs):  # noqa: E501
        """Settlement messages by settlement date and period (SMSG)  # noqa: E501

        Returns settlement messages generated by the SAA for a given settlement period, relating to the data  for a settlement run.                Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_messages_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_period', 'settlement_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_messages_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_messages_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_messages_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/messages/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get(self, bid_offer, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Settlement bid-offer stacks by settlement period (ISPSTACK)  # noqa: E501

        Returns detailed system prices generated by the latest calculation run for a given settlement period.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get(bid_offer, settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bid_offer: Filter if bid or offer data is to be returned. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param int settlement_period: The settlement period for the filter. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get_with_http_info(bid_offer, settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get_with_http_info(bid_offer, settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get_with_http_info(self, bid_offer, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Settlement bid-offer stacks by settlement period (ISPSTACK)  # noqa: E501

        Returns detailed system prices generated by the latest calculation run for a given settlement period.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get_with_http_info(bid_offer, settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bid_offer: Filter if bid or offer data is to be returned. (required)
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param int settlement_period: The settlement period for the filter. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bid_offer', 'settlement_date', 'settlement_period', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bid_offer' is set
        if ('bid_offer' not in params or
                params['bid_offer'] is None):
            raise ValueError("Missing the required parameter `bid_offer` when calling `balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bid_offer' in params:
            path_params['bidOffer'] = params['bid_offer']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/stack/all/{bidOffer}/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_summary_settlement_date_settlement_period_get(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Settlement calculation summary (ISPSTACK, DISEBSP, MID, NETBSAD)  # noqa: E501

        Returns the settlement calculation summary for the requested settlement period.  Data is derived from the following datasets: ISPSTACK, DISEBSP, MID, NETBSAD                In JSON format, decimal values are returned as strings to avoid loss of precision.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_summary_settlement_date_settlement_period_get(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param int settlement_period: This should be an integer from 1-50 inclusive. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_summary_settlement_date_settlement_period_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_summary_settlement_date_settlement_period_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_summary_settlement_date_settlement_period_get_with_http_info(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Settlement calculation summary (ISPSTACK, DISEBSP, MID, NETBSAD)  # noqa: E501

        Returns the settlement calculation summary for the requested settlement period.  Data is derived from the following datasets: ISPSTACK, DISEBSP, MID, NETBSAD                In JSON format, decimal values are returned as strings to avoid loss of precision.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_summary_settlement_date_settlement_period_get_with_http_info(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: This must be in the format yyyy-MM-dd. (required)
        :param int settlement_period: This should be an integer from 1-50 inclusive. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'settlement_period', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_summary_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_summary_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_summary_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/summary/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_system_prices_settlement_date_get(self, settlement_date, **kwargs):  # noqa: E501
        """Settlement system prices by settlement date (DISEBSP)  # noqa: E501

        Returns settlement system buy and sell prices generated by the SAA for a given settlement day, relating to  the data for a settlement run.                For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_system_prices_settlement_date_get(settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_system_prices_settlement_date_get_with_http_info(settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_system_prices_settlement_date_get_with_http_info(settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_system_prices_settlement_date_get_with_http_info(self, settlement_date, **kwargs):  # noqa: E501
        """Settlement system prices by settlement date (DISEBSP)  # noqa: E501

        Returns settlement system buy and sell prices generated by the SAA for a given settlement day, relating to  the data for a settlement run.                For each settlement period within the range, only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_system_prices_settlement_date_get_with_http_info(settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_system_prices_settlement_date_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_system_prices_settlement_date_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/system-prices/{settlementDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_settlement_system_prices_settlement_date_settlement_period_get(self, settlement_period, settlement_date, **kwargs):  # noqa: E501
        """Settlement system prices by settlement date and period (DISEBSP)  # noqa: E501

        Returns settlement system buy and sell prices generated by the SAA for a given settlement period, relating to  the data for a settlement run.                Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_system_prices_settlement_date_settlement_period_get(settlement_period, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_settlement_system_prices_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_settlement_system_prices_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, **kwargs)  # noqa: E501
            return data

    def balancing_settlement_system_prices_settlement_date_settlement_period_get_with_http_info(self, settlement_period, settlement_date, **kwargs):  # noqa: E501
        """Settlement system prices by settlement date and period (DISEBSP)  # noqa: E501

        Returns settlement system buy and sell prices generated by the SAA for a given settlement period, relating to  the data for a settlement run.                Only messages generated for the latest settlement run are returned.                Settlement date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_settlement_system_prices_settlement_date_settlement_period_get_with_http_info(settlement_period, settlement_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param date settlement_date: The settlement date to filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_period', 'settlement_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_settlement_system_prices_settlement_date_settlement_period_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_settlement_system_prices_settlement_date_settlement_period_get`")  # noqa: E501
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_settlement_system_prices_settlement_date_settlement_period_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'settlement_period' in params:
            path_params['settlementPeriod'] = params['settlement_period']  # noqa: E501
        if 'settlement_date' in params:
            path_params['settlementDate'] = params['settlement_date']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/settlement/system-prices/{settlementDate}/{settlementPeriod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'publish_time': 'datetime',
        'bsc_party_id': 'str',
        'credit_default_level': 'int',
        'entered_default_settlement_date': 'date',
        'entered_default_settlement_period': 'int',
        'cleared_default_settlement_date': 'date',
        'cleared_default_settlement_period': 'int',
        'cleared_default_text': 'str'
    }

    attribute_map = {
        'dataset': 'dataset',
        'publish_time': 'publishTime',
        'bsc_party_id': 'bscPartyId',
        'credit_default_level': 'creditDefaultLevel',
        'entered_default_settlement_date': 'enteredDefaultSettlementDate',
        'entered_default_settlement_period': 'enteredDefaultSettlementPeriod',
        'cleared_default_settlement_date': 'clearedDefaultSettlementDate',
        'cleared_default_settlement_period': 'clearedDefaultSettlementPeriod',
        'cleared_default_text': 'clearedDefaultText'
    }

    def __init__(self, dataset=None, publish_time=None, bsc_party_id=None, credit_default_level=None, entered_default_settlement_date=None, entered_default_settlement_period=None, cleared_default_settlement_date=None, cleared_default_settlement_period=None, cleared_default_text=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._publish_time = None
        self._bsc_party_id = None
        self._credit_default_level = None
        self._entered_default_settlement_date = None
        self._entered_default_settlement_period = None
        self._cleared_default_settlement_date = None
        self._cleared_default_settlement_period = None
        self._cleared_default_text = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if publish_time is not None:
            self.publish_time = publish_time
        if bsc_party_id is not None:
            self.bsc_party_id = bsc_party_id
        if credit_default_level is not None:
            self.credit_default_level = credit_default_level
        if entered_default_settlement_date is not None:
            self.entered_default_settlement_date = entered_default_settlement_date
        if entered_default_settlement_period is not None:
            self.entered_default_settlement_period = entered_default_settlement_period
        if cleared_default_settlement_date is not None:
            self.cleared_default_settlement_date = cleared_default_settlement_date
        if cleared_default_settlement_period is not None:
            self.cleared_default_settlement_period = cleared_default_settlement_period
        if cleared_default_text is not None:
            self.cleared_default_text = cleared_default_text

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param dataset: The dataset of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def bsc_party_id(self):
        """Gets the bsc_party_id of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The bsc_party_id of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: str
        """
        return self._bsc_party_id

    @bsc_party_id.setter
    def bsc_party_id(self, bsc_party_id):
        """Sets the bsc_party_id of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param bsc_party_id: The bsc_party_id of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: str
        """

        self._bsc_party_id = bsc_party_id

    @property
    def credit_default_level(self):
        """Gets the credit_default_level of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The credit_default_level of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: int
        """
        return self._credit_default_level

    @credit_default_level.setter
    def credit_default_level(self, credit_default_level):
        """Sets the credit_default_level of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param credit_default_level: The credit_default_level of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: int
        """

        self._credit_default_level = credit_default_level

    @property
    def entered_default_settlement_date(self):
        """Gets the entered_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The entered_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: date
        """
        return self._entered_default_settlement_date

    @entered_default_settlement_date.setter
    def entered_default_settlement_date(self, entered_default_settlement_date):
        """Sets the entered_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param entered_default_settlement_date: The entered_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: date
        """

        self._entered_default_settlement_date = entered_default_settlement_date

    @property
    def entered_default_settlement_period(self):
        """Gets the entered_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The entered_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: int
        """
        return self._entered_default_settlement_period

    @entered_default_settlement_period.setter
    def entered_default_settlement_period(self, entered_default_settlement_period):
        """Sets the entered_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param entered_default_settlement_period: The entered_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: int
        """

        self._entered_default_settlement_period = entered_default_settlement_period

    @property
    def cleared_default_settlement_date(self):
        """Gets the cleared_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The cleared_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: date
        """
        return self._cleared_default_settlement_date

    @cleared_default_settlement_date.setter
    def cleared_default_settlement_date(self, cleared_default_settlement_date):
        """Sets the cleared_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param cleared_default_settlement_date: The cleared_default_settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: date
        """

        self._cleared_default_settlement_date = cleared_default_settlement_date

    @property
    def cleared_default_settlement_period(self):
        """Gets the cleared_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The cleared_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: int
        """
        return self._cleared_default_settlement_period

    @cleared_default_settlement_period.setter
    def cleared_default_settlement_period(self, cleared_default_settlement_period):
        """Sets the cleared_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param cleared_default_settlement_period: The cleared_default_settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: int
        """

        self._cleared_default_settlement_period = cleared_default_settlement_period

    @property
    def cleared_default_text(self):
        """Gets the cleared_default_text of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501


        :return: The cleared_default_text of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :rtype: str
        """
        return self._cleared_default_text

    @cleared_default_text.setter
    def cleared_default_text(self, cleared_default_text):
        """Sets the cleared_default_text of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.


        :param cleared_default_text: The cleared_default_text of this InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse.  # noqa: E501
        :type: str
        """

        self._cleared_default_text = cleared_default_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'publish_time': 'datetime',
        'forecast_date': 'date',
        'surplus': 'int'
    }

    attribute_map = {
        'dataset': 'dataset',
        'publish_time': 'publishTime',
        'forecast_date': 'forecastDate',
        'surplus': 'surplus'
    }

    def __init__(self, dataset=None, publish_time=None, forecast_date=None, surplus=None):  # noqa: E501
        """InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._publish_time = None
        self._forecast_date = None
        self._surplus = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if publish_time is not None:
            self.publish_time = publish_time
        if forecast_date is not None:
            self.forecast_date = forecast_date
        if surplus is not None:
            self.surplus = surplus

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.


        :param dataset: The dataset of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def forecast_date(self):
        """Gets the forecast_date of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501


        :return: The forecast_date of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :rtype: date
        """
        return self._forecast_date

    @forecast_date.setter
    def forecast_date(self, forecast_date):
        """Sets the forecast_date of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.


        :param forecast_date: The forecast_date of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :type: date
        """

        self._forecast_date = forecast_date

    @property
    def surplus(self):
        """Gets the surplus of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501


        :return: The surplus of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :rtype: int
        """
        return self._surplus

    @surplus.setter
    def surplus(self, surplus):
        """Sets the surplus of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.


        :param surplus: The surplus of this InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily.  # noqa: E501
        :type: int
        """

        self._surplus = surplus

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesMiscTemperatureData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'measurement_date': 'date',
        'publish_time': 'datetime',
        'temperature': 'float',
        'temperature_reference_average': 'float',
        'temperature_reference_high': 'float',
        'temperature_reference_low': 'float'
    }

    attribute_map = {
        'measurement_date': 'measurementDate',
        'publish_time': 'publishTime',
        'temperature': 'temperature',
        'temperature_reference_average': 'temperatureReferenceAverage',
        'temperature_reference_high': 'temperatureReferenceHigh',
        'temperature_reference_low': 'temperatureReferenceLow'
    }

    def __init__(self, measurement_date=None, publish_time=None, temperature=None, temperature_reference_average=None, temperature_reference_high=None, temperature_reference_low=None):  # noqa: E501
        """InsightsApiModelsResponsesMiscTemperatureData - a model defined in Swagger"""  # noqa: E501
        self._measurement_date = None
        self._publish_time = None
        self._temperature = None
        self._temperature_reference_average = None
        self._temperature_reference_high = None
        self._temperature_reference_low = None
        self.discriminator = None
        if measurement_date is not None:
            self.measurement_date = measurement_date
        if publish_time is not None:
            self.publish_time = publish_time
        if temperature is not None:
            self.temperature = temperature
        if temperature_reference_average is not None:
            self.temperature_reference_average = temperature_reference_average
        if temperature_reference_high is not None:
            self.temperature_reference_high = temperature_reference_high
        if temperature_reference_low is not None:
            self.temperature_reference_low = temperature_reference_low

    @property
    def measurement_date(self):
        """Gets the measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: date
        """
        return self._measurement_date

    @measurement_date.setter
    def measurement_date(self, measurement_date):
        """Sets the measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.


        :param measurement_date: The measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: date
        """

        self._measurement_date = measurement_date

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesMiscTemperatureData.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def temperature(self):
        """Gets the temperature of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature: The temperature of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def temperature_reference_average(self):
        """Gets the temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature_reference_average

    @temperature_reference_average.setter
    def temperature_reference_average(self, temperature_reference_average):
        """Sets the temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature_reference_average: The temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature_reference_average = temperature_reference_average

    @property
    def temperature_reference_high(self):
        """Gets the temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature_reference_high

    @temperature_reference_high.setter
    def temperature_reference_high(self, temperature_reference_high):
        """Sets the temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature_reference_high: The temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature_reference_high = temperature_reference_high

    @property
    def temperature_reference_low(self):
        """Gets the temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature_reference_low

    @temperature_reference_low.setter
    def temperature_reference_low(self, temperature_reference_low):
        """Sets the temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature_reference_low: The temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature_reference_low = temperature_reference_low

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesMiscTemperatureData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesMiscTemperatureData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.balancing_services_adjustment___net_api import BalancingServicesAdjustmentNetApi  # noqa: E501
from elexonpy.rest import ApiException


class TestBalancingServicesAdjustmentNetApi(unittest.TestCase):
    """BalancingServicesAdjustmentNetApi unit test stubs"""

    def setUp(self):
        self.api = BalancingServicesAdjustmentNetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_balancing_nonbm_netbsad_events_get(self):
        """Test case for balancing_nonbm_netbsad_events_get

        Net balancing services adjustment events (NETBSAD)  # noqa: E501
        """
        pass

    def test_balancing_nonbm_netbsad_get(self):
        """Test case for balancing_nonbm_netbsad_get

        Net balancing services adjustment time series (NETBSAD)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class BalancingMechanismDynamicApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def balancing_dynamic_all_get(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Market-wide dynamic data (SEL, SIL, MZT, MNZT, MDV, MDP, NTB, NTO, NDZ)  # noqa: E501

        This endpoint provides the dynamic data for multiple requested BMUs or all BMUs, excluding dynamic rate data.  It returns the data valid for a single settlement period. This includes a snapshot of data valid at the start  of the settlement period, and any changes published during that settlement period.                By default, all of the relevant datasets are returned: SIL, SEL, NDZ, NTB, NTO, MZT, MNZT, MDV & MDP.  The results from each dataset are transformed to a common response model, with the common integer field *Value*  mapped from the fields *Level*, *Period*, *Volume* or *Notice* in the original dataset, as relevant.                The settlement period must be specified as a date and settlement period. The date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_all_get(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date or datetime to filter. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param list[str] dataset: Datasets to filter. If omitted, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_dynamic_all_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_dynamic_all_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def balancing_dynamic_all_get_with_http_info(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Market-wide dynamic data (SEL, SIL, MZT, MNZT, MDV, MDP, NTB, NTO, NDZ)  # noqa: E501

        This endpoint provides the dynamic data for multiple requested BMUs or all BMUs, excluding dynamic rate data.  It returns the data valid for a single settlement period. This includes a snapshot of data valid at the start  of the settlement period, and any changes published during that settlement period.                By default, all of the relevant datasets are returned: SIL, SEL, NDZ, NTB, NTO, MZT, MNZT, MDV & MDP.  The results from each dataset are transformed to a common response model, with the common integer field *Value*  mapped from the fields *Level*, *Period*, *Volume* or *Notice* in the original dataset, as relevant.                The settlement period must be specified as a date and settlement period. The date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_all_get_with_http_info(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date or datetime to filter. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param list[str] dataset: Datasets to filter. If omitted, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'settlement_period', 'bm_unit', 'dataset', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_dynamic_all_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_dynamic_all_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_dynamic_all_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'settlement_date' in params:
            query_params.append(('settlementDate', params['settlement_date']))  # noqa: E501
        if 'settlement_period' in params:
            query_params.append(('settlementPeriod', params['settlement_period']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
            collection_formats['dataset'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/dynamic/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_dynamic_get(self, bm_unit, snapshot_at, **kwargs):  # noqa: E501
        """Dynamic data per BMU (SEL, SIL, MZT, MNZT, MDV, MDP, NTB, NTO, NDZ)  # noqa: E501

        This endpoint provides the dynamic data for a requested BMU, excluding physical rate data.  It returns a \"snapshot\" of data valid at a given time, and optionally a time series of changes over a requested interval.                By default, all of the relevant datasets are returned: SIL, SEL, NDZ, NTB, NTO, MZT, MNZT, MDV, MDP.  The results from each dataset are transformed to a common response model, with the common integer field *Value*  mapped from the fields *Level*, *Period*, *Volume* or *Notice* in the original dataset, as relevant.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_get(bm_unit, snapshot_at, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bm_unit: The BM Unit to query. (required)
        :param datetime snapshot_at: When to retrieve a snapshot of data at.  That is, the latest datapoint before this time will be returned for each dataset. (required)
        :param datetime until: When to retrieve data until.  Data from the snapshot until this time will be returned.
        :param int snapshot_at_settlement_period: The settlement period to retrieve a snapshot of data at.  If provided, the time part of SnapshotAt will be ignored.
        :param int until_settlement_period: The settlement period to retrieve data until.  If provided, the time part of Until will be ignored.
        :param list[str] dataset: Datasets to filter. If omitted, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_dynamic_get_with_http_info(bm_unit, snapshot_at, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_dynamic_get_with_http_info(bm_unit, snapshot_at, **kwargs)  # noqa: E501
            return data

    def balancing_dynamic_get_with_http_info(self, bm_unit, snapshot_at, **kwargs):  # noqa: E501
        """Dynamic data per BMU (SEL, SIL, MZT, MNZT, MDV, MDP, NTB, NTO, NDZ)  # noqa: E501

        This endpoint provides the dynamic data for a requested BMU, excluding physical rate data.  It returns a \"snapshot\" of data valid at a given time, and optionally a time series of changes over a requested interval.                By default, all of the relevant datasets are returned: SIL, SEL, NDZ, NTB, NTO, MZT, MNZT, MDV, MDP.  The results from each dataset are transformed to a common response model, with the common integer field *Value*  mapped from the fields *Level*, *Period*, *Volume* or *Notice* in the original dataset, as relevant.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_get_with_http_info(bm_unit, snapshot_at, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bm_unit: The BM Unit to query. (required)
        :param datetime snapshot_at: When to retrieve a snapshot of data at.  That is, the latest datapoint before this time will be returned for each dataset. (required)
        :param datetime until: When to retrieve data until.  Data from the snapshot until this time will be returned.
        :param int snapshot_at_settlement_period: The settlement period to retrieve a snapshot of data at.  If provided, the time part of SnapshotAt will be ignored.
        :param int until_settlement_period: The settlement period to retrieve data until.  If provided, the time part of Until will be ignored.
        :param list[str] dataset: Datasets to filter. If omitted, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bm_unit', 'snapshot_at', 'until', 'snapshot_at_settlement_period', 'until_settlement_period', 'dataset', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_dynamic_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bm_unit' is set
        if ('bm_unit' not in params or
                params['bm_unit'] is None):
            raise ValueError("Missing the required parameter `bm_unit` when calling `balancing_dynamic_get`")  # noqa: E501
        # verify the required parameter 'snapshot_at' is set
        if ('snapshot_at' not in params or
                params['snapshot_at'] is None):
            raise ValueError("Missing the required parameter `snapshot_at` when calling `balancing_dynamic_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
        if 'snapshot_at' in params:
            query_params.append(('snapshotAt', params['snapshot_at']))  # noqa: E501
        if 'until' in params:
            query_params.append(('until', params['until']))  # noqa: E501
        if 'snapshot_at_settlement_period' in params:
            query_params.append(('snapshotAtSettlementPeriod', params['snapshot_at_settlement_period']))  # noqa: E501
        if 'until_settlement_period' in params:
            query_params.append(('untilSettlementPeriod', params['until_settlement_period']))  # noqa: E501
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
            collection_formats['dataset'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/dynamic', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_dynamic_rates_all_get(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Market-wide rate data (RDRE, RURE, RDRI, RURI)  # noqa: E501

        This endpoint provides market-wide physical rate data, for all BMUs or a requested set of multiple BMUs.  It returns the data valid for a given settlement period. This includes a snapshot of data valid at the start  of the settlement period, and any changes published during that settlement period.                The settlement period to query can be specified as a date and settlement period. The settlement date must be provided in the format yyyy-MM-dd.    By default, all of the relevant datasets are returned: RDRE, RURE, RDRI, RURI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_rates_all_get(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param list[str] dataset: Datasets to return. If omitted, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_dynamic_rates_all_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_dynamic_rates_all_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def balancing_dynamic_rates_all_get_with_http_info(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Market-wide rate data (RDRE, RURE, RDRI, RURI)  # noqa: E501

        This endpoint provides market-wide physical rate data, for all BMUs or a requested set of multiple BMUs.  It returns the data valid for a given settlement period. This includes a snapshot of data valid at the start  of the settlement period, and any changes published during that settlement period.                The settlement period to query can be specified as a date and settlement period. The settlement date must be provided in the format yyyy-MM-dd.    By default, all of the relevant datasets are returned: RDRE, RURE, RDRI, RURI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_rates_all_get_with_http_info(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param list[str] dataset: Datasets to return. If omitted, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'settlement_period', 'bm_unit', 'dataset', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_dynamic_rates_all_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_dynamic_rates_all_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_dynamic_rates_all_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'settlement_date' in params:
            query_params.append(('settlementDate', params['settlement_date']))  # noqa: E501
        if 'settlement_period' in params:
            query_params.append(('settlementPeriod', params['settlement_period']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
            collection_formats['dataset'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/dynamic/rates/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_dynamic_rates_get(self, bm_unit, snapshot_at, **kwargs):  # noqa: E501
        """Rate data per BMU (RDRE, RURE, RDRI, RURI)  # noqa: E501

        This endpoint provides the physical rate data for a requested BMU.  It returns a \"snapshot\" of data valid at a given time, and optionally a time series of changes over a requested interval.                By default, all of the relevant datasets are returned: RDRE, RURE, RDRI, RURI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_rates_get(bm_unit, snapshot_at, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bm_unit: The BM Unit to query. (required)
        :param datetime snapshot_at: When to retrieve a snapshot of data at.  That is, the latest datapoint before this time will be returned for each dataset. (required)
        :param datetime until: When to retrieve data until.  Data from the snapshot until this time will be returned.
        :param int snapshot_at_settlement_period: The settlement period to retrieve a snapshot of data at.  If provided, the time part of SnapshotAt will be ignored.
        :param int until_settlement_period: The settlement period to retrieve data until.  If provided, the time part of Until will be ignored.
        :param list[str] dataset: Datasets to filter. If empty, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_dynamic_rates_get_with_http_info(bm_unit, snapshot_at, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_dynamic_rates_get_with_http_info(bm_unit, snapshot_at, **kwargs)  # noqa: E501
            return data

    def balancing_dynamic_rates_get_with_http_info(self, bm_unit, snapshot_at, **kwargs):  # noqa: E501
        """Rate data per BMU (RDRE, RURE, RDRI, RURI)  # noqa: E501

        This endpoint provides the physical rate data for a requested BMU.  It returns a \"snapshot\" of data valid at a given time, and optionally a time series of changes over a requested interval.                By default, all of the relevant datasets are returned: RDRE, RURE, RDRI, RURI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_dynamic_rates_get_with_http_info(bm_unit, snapshot_at, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bm_unit: The BM Unit to query. (required)
        :param datetime snapshot_at: When to retrieve a snapshot of data at.  That is, the latest datapoint before this time will be returned for each dataset. (required)
        :param datetime until: When to retrieve data until.  Data from the snapshot until this time will be returned.
        :param int snapshot_at_settlement_period: The settlement period to retrieve a snapshot of data at.  If provided, the time part of SnapshotAt will be ignored.
        :param int until_settlement_period: The settlement period to retrieve data until.  If provided, the time part of Until will be ignored.
        :param list[str] dataset: Datasets to filter. If empty, all datasets will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bm_unit', 'snapshot_at', 'until', 'snapshot_at_settlement_period', 'until_settlement_period', 'dataset', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_dynamic_rates_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bm_unit' is set
        if ('bm_unit' not in params or
                params['bm_unit'] is None):
            raise ValueError("Missing the required parameter `bm_unit` when calling `balancing_dynamic_rates_get`")  # noqa: E501
        # verify the required parameter 'snapshot_at' is set
        if ('snapshot_at' not in params or
                params['snapshot_at'] is None):
            raise ValueError("Missing the required parameter `snapshot_at` when calling `balancing_dynamic_rates_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
        if 'snapshot_at' in params:
            query_params.append(('snapshotAt', params['snapshot_at']))  # noqa: E501
        if 'until' in params:
            query_params.append(('until', params['until']))  # noqa: E501
        if 'snapshot_at_settlement_period' in params:
            query_params.append(('snapshotAtSettlementPeriod', params['snapshot_at_settlement_period']))  # noqa: E501
        if 'until_settlement_period' in params:
            query_params.append(('untilSettlementPeriod', params['until_settlement_period']))  # noqa: E501
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
            collection_formats['dataset'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/dynamic/rates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
